Message class

For build and parse request/reply message Ice Protocol:

  magic 0-4(Int)             <--- header begin
  ProtocolVersion, EncodingVersion
  MessgeType, Compress
  totalBytes
  RequestId(Int)             <--- body begin
  identity(String)
  0 0 <- List<facet>
  operation(String)
  OperationMode(Byte)
  Context(Map)
  ParamsBytes + 6 = Encapsulation.size(Int)
  1,1 (2Byte)
  Param1                     <--- param begin
  Param2

Constructors

Message({required Identity? identity, required String operation, required OperationMode operationMode, required Context context, required Header header, required int? requestId, required bool sync, WriteParams writeParams = _writeEmptyParams, ReplyStatus? status})
Message.reply(ReplyStatus status, WriteParams writeParams, Message request)
factory

Properties

context Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
final
identity Identity?
final
operation String
final
operationMode OperationMode
final
requestId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ReplyStatus?
getter/setter pair
sync bool
final
writeParams WriteParams
final

Methods

encodeReply() OutputStream
return reply message, it is diff from request
encodeRequest() OutputStream
return request message
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseHeader(InputStream input) Header